Scriptname ZSH_V2_AeonbarrScript01 extends Quest  
;-------------------------------------------------------------------------------
; This script handles the summoning and banishing of Aeonbarr
;-------------------------------------------------------------------------------

;----------------------------------------------------------------------------------------------
;	PROPERTIES
;----------------------------------------------------------------------------------------------
Activator Property SummonTargetFXActivator Auto
Activator Property ZSH_BanishActivator Auto
Activator Property XMarkerActivator Auto

Actor Property Aeonbarr Auto

EffectShader Property ZSH_AeonbarrUnsummon Auto

Faction Property ZSH_AeonbarrAllyFaction Auto

GlobalVariable Property ZSH_AllowSummon Auto
GlobalVariable Property ZSH_MCM_Ethereal Auto
GlobalVariable Property ZSH_MCM_SummonRotation Auto
GlobalVariable Property ZSH_MCM_SpellOrPower Auto
GlobalVariable Property ZSH_MCM_Quest Auto

ImageSpaceModifier Property FadeToBlackHoldImod Auto
ImageSpaceModifier Property MAGBanishImod Auto

Location Property ZSH_HorseLocation Auto

Message Property ZSH_SummonHorseMessage01 Auto

ObjectReference Property AeonbarrHomeMarker Auto
ObjectReference Property AeonbarrNirnMarker Auto
ObjectReference SpawnMarker

Quest Property ZSH_AeonbarrQuest Auto
Quest Property ZSH_BlackstedQuest Auto

Spell Property ZSH_Summon_01_PowerSpell Auto
Spell Property ZSH_Summon_MasterAb Auto

WorldSpace Property ArenaWorld Auto

;----------------------------------------------------------------------------------------------
;	EVENTS
;----------------------------------------------------------------------------------------------
Event OnInit()
If !Game.GetPlayer().IsInFaction(ZSH_AeonbarrAllyFaction)
	Game.GetPlayer().AddToFaction(ZSH_AeonbarrAllyFaction)
Endif
EndEvent
;----------------------------------------------------------------------------------------------
;	SPELL FUNCTIONS
;----------------------------------------------------------------------------------------------
Function CastSummonSpell(Actor akCaster)
if ZSH_AllowSummon.GetValue() == 1

IF (Aeonbarr.GetParentCell() == AeonbarrHomeMarker.GetParentCell()) || (Aeonbarr.IsDisabled())
	SetSpawnMarker(akCaster)
	RequestSummon()
ELSE
	Int Choice = ZSH_SummonHorseMessage01.Show()
		If Choice == 0
			SetSpawnMarker(akCaster)
			BanishProcedure()
			RequestSummon()
		Elseif Choice == 1
			BanishProcedure()
		Endif
ENDIF

endif
EndFunction

Function ResetAeonbarr()
	If !(Aeonbarr.GetParentCell() == AeonbarrHomeMarker.GetParentCell())
		SetSpawnMarker(Game.GetPlayer())
		BanishProcedure()
		RequestSummon()
	Endif
EndFunction

Function SetSpawnMarker(Actor akCaster)
	SpawnMarker = akCaster.PlaceAtMe(XMarkerActivator)
	SpawnMarker.MoveTo(akCaster, 200.0 * Math.Sin(akCaster.GetAngleZ()), 200.0 * Math.Cos(akCaster.GetAngleZ()), 0)
	
	Float FacingRotation = ((akCaster.GetAngleZ())+(ZSH_MCM_SummonRotation.GetValue() as Float)) as Float
	SpawnMarker.SetAngle(0, 0, FacingRotation)

	AeonbarrNirnMarker.MoveTo(SpawnMarker)
	SpawnMarker.Delete()
EndFunction
;----------------------------------------------------------------------------------------------
;	SUMMONING FUNCTIONS
;----------------------------------------------------------------------------------------------
Function RequestSummon()
MAGBanishImod.Apply(1)
	SummonProcedure()
EndFunction

Function SummonProcedure()
ZSH_AllowSummon.SetValue(0)

IF Aeonbarr.IsEnabled()
	BanishProcedure()
ELSE
	Aeonbarr.Enable()
	FullHeal()
	Aeonbarr.SetAlpha(0, False)
	Aeonbarr.MoveTo(AeonbarrNirnMarker)
	Aeonbarr.PlaceAtMe(SummonTargetFXActivator)
	Aeonbarr.SetAlpha(0.1, False)
	If ZSH_MCM_Ethereal.GetValue() > 0
		Aeonbarr.SetAlpha(0.33, True)
	Else
		Aeonbarr.SetAlpha(1, True)
	Endif
ENDIF

	(ZSH_AeonbarrQuest as ZSH_V2_AeonbarrScript02).SetAttributes()
	ZSH_AllowSummon.SetValue(1)
EndFunction

Function KeySummon()
	If (ZSH_MCM_SpellOrPower.GetValue() == 1)
		ZSH_Summon_01_PowerSpell.Cast(Game.GetPlayer())
	Endif
EndFunction
;----------------------------------------------------------------------------------------------
;	BANISHING FUNCTIONS
;----------------------------------------------------------------------------------------------
Function BanishProcedure()
ZSH_AllowSummon.SetValue(0)

IF Aeonbarr.IsDisabled()
	RequestSummon()
ELSE
	If (Game.GetPlayer().IsOnMount()) && (Game.GetPlayersLastRiddenHorse() == Aeonbarr)
		Aeonbarr.PlaceAtMe(ZSH_BanishActivator)
		Aeonbarr.MoveTo(AeonbarrHomeMarker)
	Else
		Aeonbarr.StopCombat()
		ZSH_AeonbarrUnsummon.Play(Aeonbarr)
		Aeonbarr.PlaceAtMe(ZSH_BanishActivator)
		Aeonbarr.SetAlpha(0.3, True)
		Utility.Wait(1)
		Aeonbarr.MoveTo(AeonbarrHomeMarker)

		While !(Aeonbarr.GetParentCell() == AeonbarrHomeMarker.GetParentCell())
			Utility.Wait(0.1)
		EndWhile

		ZSH_AeonbarrUnsummon.Stop(Aeonbarr)
	Endif
	Aeonbarr.Disable()
ENDIF

	ZSH_AllowSummon.SetValue(1)
EndFunction

Function MountedBanish()
	If (Game.GetPlayer().IsOnMount()) && (Game.GetPlayersLastRiddenHorse() == Aeonbarr)
		BanishProcedure()
	Endif
EndFunction
;----------------------------------------------------------------------------------------------
;	MARK AND RETURN FUNCTIONS
;----------------------------------------------------------------------------------------------
ObjectReference Property ZSH_AeonbarrMarker00 Auto
ObjectReference Property ZSH_AeonbarrMarker01 Auto
ObjectReference Property ZSH_AeonbarrMarker02 Auto
ObjectReference AeonbarrMarker
Message Property ZSH_AeonbarrMarkMessage Auto
Message Property ZSH_AeonbarrReturnMessage Auto

SoundCategory Property AudioCategory01 Auto
SoundCategory Property AudioCategory02 Auto

Function AeonbarrMark()
IF (Game.GetPlayer().IsOnMount()) && (Game.GetPlayersLastRiddenHorse() == Aeonbarr) && (Game.GetPlayer().GetParentCell() == Aeonbarr.GetParentCell()) && !(Game.GetPlayer().GetWorldSpace() == ArenaWorld)
Int Choice = ZSH_AeonbarrMarkMessage.Show() as Int
	If Choice == 0
		ZSH_AeonbarrMarker00.MoveTo(Aeonbarr)
		Debug.Notification("Marker set.")
	Elseif Choice == 1
		ZSH_AeonbarrMarker01.MoveTo(Aeonbarr)
		Debug.Notification("Marker set.")
	Elseif Choice == 2
		ZSH_AeonbarrMarker02.MoveTo(Aeonbarr)
		Debug.Notification("Marker set.")
	Else
		Return
	Endif
ENDIF
EndFunction

Function AeonbarrReturn()
IF (Game.GetPlayer().IsOnMount()) && (Game.GetPlayersLastRiddenHorse() == Aeonbarr) && ((Game.GetPlayer().GetParentCell() == Aeonbarr.GetParentCell()) || (Game.GetPlayer().GetWorldSpace() == Aeonbarr.GetWorldSpace()))
	if Game.GetPlayer().GetWorldSpace() == ArenaWorld
		AeonbarrMarker = ZSH_AeonbarrMarker00
	else
		Int Choice = ZSH_AeonbarrReturnMessage.Show() as Int
		If Choice == 0
			AeonbarrMarker = ZSH_AeonbarrMarker00
		Elseif Choice == 1
			AeonbarrMarker = ZSH_AeonbarrMarker01
		Elseif Choice == 2
			AeonbarrMarker = ZSH_AeonbarrMarker02
		Else
			Return
		Endif
	endif

If !(AeonbarrMarker.GetParentCell() == AeonbarrHomeMarker.GetParentCell())
IF Aeonbarr.GetDistance(AeonbarrMarker) >= 4400
	Game.DisablePlayerControls()	
	FadeToBlackHoldImod.ApplyCrossFade(0.1)						
	Utility.Wait(0.2)
	Game.GetPlayer().SetGhost(True)
	Aeonbarr.SetGhost(True)

	Aeonbarr.MoveTo(AeonbarrMarker)
	Utility.Wait(0.1)
	Game.GetPlayer().MoveTo(Aeonbarr,10,0,0)
	AudioCategory01.Mute()
	AudioCategory02.Mute()

	Int Attempts = 0
	(ZSH_AeonbarrQuest as ZSH_V2_AeonbarrScript02).SetAttributes()
	WHILE !(Game.GetPlayer().IsOnMount()) && (Attempts < 10)
		Game.GetPlayer().SetAngle(0,0,Game.GetPlayer().GetHeadingAngle(Aeonbarr))
		Aeonbarr.Activate(Game.GetPlayer())
		Attempts = (Attempts+1)
		Utility.Wait(0.1)
	ENDWHILE

	ImageSpaceModifier.RemoveCrossFade(0.1)
	Game.FadeOutGame(FALSE,TRUE,3,1.5)
	AudioCategory01.Unmute()
	AudioCategory02.Unmute()
	Aeonbarr.PlaceAtMe(SummonTargetFXActivator)
	Game.GetPlayer().SetGhost(False)
	Aeonbarr.SetGhost(False)
	Game.EnablePlayerControls()
ELSE
	Debug.MessageBox("Marker is to close to return to.")
ENDIF
Else
	Debug.MessageBox("You haven't marked a location to travel to.")
Endif
ENDIF
EndFunction
;----------------------------------------------------------------------------------------------
;	MISC FUNCTIONS
;----------------------------------------------------------------------------------------------
Event OnMenuClose(String MenuName)
if (MenuName == "Journal Menu") && (ZSH_MCM_Quest.GetValue() == 1) && (ZSH_BlackstedQuest.GetStage() < 50)
	UnRegisterForMenu("Journal Menu")
	ZSH_BlackstedQuest.SetStage(100)
	Game.GetPlayer().AddSpell(ZSH_Summon_MasterAb)
endif
EndEvent

Function SkipQuest()
RegisterForMenu("Journal Menu")
EndFunction

Function FullHeal()
	If !Aeonbarr.GetActorBase().IsEssential()
		Aeonbarr.GetActorBase().SetEssential(True)
	Endif
	If Aeonbarr.IsDead()
		Aeonbarr.Resurrect()
	Endif
	Aeonbarr.RestoreActorValue("Health", 9999)
	Aeonbarr.RestoreActorValue("Stamina", 9999)
EndFunction




